@@ -1,15 +1,12 @@
 import csv
-import re
-from tkinter import Entry
-from daspython.common.response import HasEntry, HasItems, HasTotal
+from daspython.common.response import HasEntry
 import uuid
 import json
 from pathlib import Path
-from requests.api import request
 from daspython.common.api import ApiMethods, Response, Token
 from daspython.services.attributes.attributeservice import AttributeService
 from daspython.services.searches.searchservice import SearchEntriesRequest, SearchService
-from daspython.services.entryfields.entryfieldservice import DisplayType, EntryFieldService
+from daspython.services.entryfields.entryfieldservice import DisplayType, EntryFieldService, InputType
 
 
 class InsertRequest():
@@ -20,8 +17,7 @@ class InsertRequest():
     ----------
         entry: dictionary
             Reprsents the  { 'field1' : 'value1', 'field2' : 'value2' ... } as an entry content.
-    '''
-    attributeId = 0
+    '''    
     entry = {}
     attributeId = 0
 
@@ -291,6 +287,17 @@ class EntryService(ApiMethods):
                 continue
             request.entry[field.get('column')] = body.entry[field.get('displayName')] 
 
+        grouped_field = next(filter(lambda x: x.get('inputType') == InputType.GroupedField.value, entry_fields.items), None)            
+
+        if not grouped_field is None:
+            custom_data = json.loads(grouped_field.get('customData'))
+            if not custom_data is None:
+                for key in body.entry:
+                    field = next(filter(lambda x: x.get('displayName') == key, custom_data.get('fields')), None)
+                    if (field is None):
+                        continue                    
+                    request.entry[field.get('column')] = body.entry[field.get('displayName')]                        
+
         if 'id' in body.entry:
             request.entry['id'] = body.entry['id']            
         
