@@ -12,6 +12,9 @@ class DisplayType(Enum):
     MODALS = 32
     TEMPLATES = 64
 
+class InputType(Enum):
+    GroupedField = 34
+
 
 class EntryFieldService(ApiMethods):
     def __init__(self, auth: Token):
